' ComSkip Automation Script
' Written by Andy Kruta
' v0.5
' 
' v0.5 11/06/2004 
' - Added ability to skip checking for location if script is run from SageTV directory.
' - Added output to IE browser for status
' 
' v0.4 10/30/2004
' - Added quotes to correct pathing problem for video directories with spaces in the name
' - Un-commented auto-detection of SageTV directory - whoops. lol
' 
' v0.3 - 10/23/2004
' - Re-wrote the auto-detection of the SAGETV directory 
' (this may take awhile to process if running on a machine with a ton of software on it)
' - Built in fail-safe check for SageTV directory in case it's not found in the registry
' - Added support for cleaning up all orphaned file types
' - Added checking to see if file was already in use before scanning 
' - Set default orphan file removal to no since this is a dangerous function
' 
' v0.2 - 10/10/2004
' - Automatic checking for existance of orphaned text files
' - Option to automatically remove orphaned text files
' - Automatic log rotating to remove old log files
' 
' v0.1 - 10/09/2004
' - Automatic determination of the SageTV directory
' - Automatic determination of the video directories
' - Checking of only files that don't have a pre-existing .txt file
' - Checking if the file is already in use
' - Report to log on the following items:
'           - Start of Script
'           - Existance of SageTV in expected directory
'           - Existance of sage.properties file in expected directory
'           - Existance of Video Directories based on items in sage.properties file
'           - Start of comskip for each video file
'           - Determination if comskip created a non-zero byte text file for each video
'           - Completion of script
' - Logging to either flat text files or event viewer
' 
' 
' 
' 
' 
' Feel free to modify this code to meet your needs, however, it would be greatly appreciated if you
' would share any modifications so they can be incorporated into this script to provide the best possible
' scripting to the public.

' Create constant values for the entire script
Const EVENT_SUCCESS = 0
Const EVENT_ERROR = 1
Const EVENT_WARNING = 2
Const ForReading = 1, ForWriting = 2, ForAppending = 8
const HKEY_LOCAL_MACHINE = &H80000002
const REG_SZ = 1
const REG_EXPAND_SZ = 2
const REG_BINARY = 3
const REG_DWORD = 4
const REG_MULTI_SZ = 7	
Const conBarSpeed=80
Const conForcedTimeOut=999999999999999999999 ' - a really really long time ;-)


' Create public and private variables
Public vid_dir(), log_type, Log_dir, rotate_logs, orphan_clean_up, old_log_date, file_in_use, showiegui
Public sage_dir
Dim WshShell, filesys, fso3, prompttext,titletext, result, vid_dir_str
Dim IEObj
Dim objProgressBar 
Dim objTextLine1
Dim objTextLine2 
Dim objQuitFlag



' This value determines the log type - it *MUST* be either text or event_log in order to get logs from this script.
log_type="text"

' This value determines if orphan text files will be automatically removed
' WARNING:  If you turn this on, it will remove *ANY* files that don't have a matching .mpg file in the video directory.  
orphan_clean_up=False

' This value determines if an IE interface will be shown to give status updates.
showiegui = True

' Setup gui feedback if it's turned On
If showiegui <> False Then
' Start Internet Explorer to show a status on
	StartIE "ComSkip Automation Script progress"    
' Set the text body showing what's going on.
	TextBody "ComSkip Automation Script progress"
' Set the first status text
	ProcessStatus "Searching for SageTV directory in script path"
End If	

' Set values for a couple of variables necessary throughout the next few steps
script_path=Replace(WScript.ScriptFullName, WScript.ScriptName,"")
Set WshShell = WScript.CreateObject("WScript.Shell")
rotate_logs=True		
Set fso3=CreateObject("scripting.filesystemobject")
old_log_date=60

' Gather the sagetv directory from a built-in registry key, and parse it for the specific information we need
' sage_dir=replace(WshShell.RegRead("HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\Installer\UserData\S-1-5-18\Components\CC1DDA8FD01EA06458135AD28CAD5A8F\54AA875C22A526543B01FBAC424D2ED0"), "SageTV.exe","")

if fso3.FileExists(script_path & "\Sage.properties") Then
	sage_dir = script_path & "\"
	If showiegui <> False Then
		ProcessStatus "SageTV directory found!"
	End If	
Else
	sage_dir=replace(Get_sagetv_dir, "SageTV.exe","")
End If	
' sage_dir="notfound"
' Check to find out if we found the SageTV directory
If sage_dir = "notfound" Then
	If showiegui <> False Then
		ProcessStatus "Searching Registry for SageTV directory"
	End if
' Setup the informational text to show the user a prompt asking for the location of the SageTV directory.
	prompttext = "Please enter the *EXACT* location of your SageTV directory with a" & _
	" trailing backslash." & vbcrlf  & vbcrlf & "  Example:  " & vbcrlf & _
	"C:\Program Files\Frey Technologies\SageTV\" 
	titletext = "SageTV Directory Not found!" 
' Ask the user for the location of the SageTV directory
	sage_dir = InputBox(prompttext, titletext, "C:\Program Files\Frey Technologies\SageTV\") 
' Check to see if the user hit cancel 
	If not sage_dir <> "" Then 
' Error out and exit	
		wscript.echo "Unable to find SageTV directory, and a directory has not been specified.  Exiting."
		If showiegui <> False Then
			CloseIE
		End If
		wscript.quit
	End If	
' Check for existance of "sagetv.exe" in specified directory
	if not fso3.FileExists(sage_dir & "sagetv.exe") Then
' Error out and exit	
			wscript.echo "Defined SageTV directory does not appear to be correct. "_
			 & "No sagetv.exe found.  Exiting!"
			If showiegui <> False Then
				CloseIE
			End If
			WScript.Quit
	End If	
' Check for existance of "comskip.exe" in specified directory
	if not fso3.FileExists(sage_dir & "comskip.exe") Then
			wscript.echo "Defined SageTV directory does not appear to be correct. "_
			& "No comskip.exe found.  Exiting!"
			If showiegui <> False Then
				CloseIE
			End If
			WScript.Quit
	End If	
' Check for existance of "comskip.ini" in specified directory
	if not fso3.FileExists(sage_dir & "comskip.ini") Then
			wscript.echo "Defined SageTV directory does not appear to be correct. "_
			& "No comskip.ini found.  Exiting!"
			If showiegui <> False Then
				CloseIE
			End If
			WScript.Quit
	End If	
End If	
' Set the location of the logs directory.  This effectively puts the logs folder inside the sagetv folder.
Log_dir=sage_dir & "logs\"
' Write data to the log indicating that the script began
result=Log_data(now & " - Begin comskip automatic scan.",EVENT_SUCCESS)

' Determine if the sage.properties file is where we think it *should* be
if fso3.FileExists(sage_dir & "Sage.properties") Then
' Read the seeker/video_storage value from the properties file to get the video directories
	result=Read_Vid_Dirs(sage_dir & "Sage.properties","seeker/video_storage")
' Write a log entry stating that we were able to find the sagetv directory
	result=Log_data(now & " - Successfully located SageTV directory.",EVENT_SUCCESS)
Else
' Write a log entry stating that we were not able to find the sagetv directory based on built-in data
	result=Log_data(now & " - Error locating SageTV directory.",EVENT_ERROR)
' Quit the script to eleviate potential errors caused by lack of information
	If showiegui <> False Then
		CloseIE
	End If
	WScript.Quit
End If	

' Perform a search for each folder found in the sage.properties file
For Each vid_dir_str In vid_dir
' Check to be sure that we're not getting an empty video directory name
	If vid_dir_str <> "" Then
' Check to be sure that the folder actually exists
		If  fso3.FolderExists(vid_dir_str) Then
' Report back that we were able to actually find the folder specified in the sage.properties file
			result=Log_data(now & " - Successfully found folder: " & vid_dir_str,EVENT_SUCCESS)
' Run the comskip routine for each folder
			result=com_skip_files(vid_dir_str)
		Else
' Report back that we were unable to find the folder specified in the sage.properties file
			result=Log_data(now & " - Unable to find folder: " & vid_dir_str,EVENT_WARNING)
		End If
	End If	
Next	
' Rotate the old logs
Rotate_old_logs

' Report back that the script has finished
result=Log_data(now & " - Completed comskip automatic scan.",EVENT_SUCCESS)
If showiegui <> False Then
	CloseIE
End If

Function com_skip_files(vid_dir_str)
' com_skip_files function - written by Andy Kruta
' This function checks for the existing of mpg files that don't have cooresponding comskip txt files
' and runs the compskip utility from the sagetv directory to create the comskip text file for the
' individual mpg, and then checks to ensure that the txt file actually has some information in it
' to ensure that comskip succeeded.

' Define some variables
	Dim fso2, fsologfolder, comfile
' Set the value of variables to use for this function
	Set fso2=CreateObject("scripting.filesystemobject")
	Set fsoLogfolder=fso2.getfolder(vid_dir_str)
' Perform actions for each file in the folder
	For each tmp in fsoLogfolder.files
' Parse the files so that we're only seeing the mpg files
		If Right(tmp,4) = ".mpg" Then
			On Error Resume Next	
			Set file_in_use = fso2.OpenTextFile(tmp.path, ForAppending)
			If Err.Number = 0 Then	
				file_in_use.close
' Check to make sure a txt file doesn't already exist
				if not fso2.FileExists(left(tmp,Len(tmp)-4) & ".txt") Then
' Check to make sure comskip.exe is located in the documented location (sagetv directory)
					if fso2.FileExists(sage_dir&"comskip.exe") Then
						Set test = fso.OpenTextFile(tmp, ForAppending)
						On Error Resume Next
						If Err.Number = 0 Then	
' Report back that we've begun processing the file					
							result=Log_data(now & " - Begin processing file: " & tmp,EVENT_SUCCESS)
' Run the comskip utility to detect commercials on the file
							result=WshShell.Run(chr(34)&sage_dir &  "comskip.exe"& Chr(34) & " "& Chr(34) &  tmp & Chr(34), 0, True)
' Check to see if a .txt file has been created after the comskip utility exits
							if not fso2.FileExists(left(tmp,Len(tmp)-4) & ".txt") Then
' Report back that comskip failed to create a txt file
								result=Log_data(now & " - Comskip failed processing file: " & tmp,EVENT_ERROR)
							Else
' Get the txt file so we can determine information about it
								Set comfile = fso2.GetFile(left(tmp,Len(tmp)-4) & ".txt")
' Determine if the comskip txt file is bigger than 0 bytes (okay, so this is a horrible hack..
' If you're actually reading this, and have ideas of how to do this better, let me know! ;-)
								If not comfile.Size > 0 Then
' Report back to the log that comskip failed at creating a valid txt file
									result=Log_data(now & " - Comskip failed processing file: " & tmp,EVENT_ERROR)
								else				
' Report back to the log that comskip succeeded. Okay, so once again, this is mostly a guess. ;-)
									result=Log_data(now & " - Comskip successfully scanned file: " & tmp,EVENT_SUCCESS)
								End If	
							End If	
						End If
					End If	
				End If	
			Else
				result=Log_data(now & " - Comskip skipping open file: " & tmp,EVENT_ERROR)
' 				WScript.Echo "File appears to be open, error - " & Err.Number
			End If	
' Now checking for orphaned text files
		Else
			If tmp <> "" Then 
' Get the extension of the file
				If Not Right(tmp,4) = ".mpg" Then
' Determine if the file has a matching mpg					
					if not fso2.FileExists(left(tmp,Len(tmp)-4) & ".mpg") Then
' Determine if we're supposed to automatically clean up the orphaned files
						If orphan_clean_up = True Then
' Grab the file resource
							set orphanfile = fso2.GetFile(tmp)
' set the variable back since I've dicked it up somewhere.
							tmp=orphanfile.name
' Remove the file
							orphanfile.Delete
' Determine the error level of deleting the file
							If Err.Number = 0 Then
' Report back to the log that we successfully deleted the file
								result=Log_data(now & " - Successfully removed orphaned file: " & tmp,EVENT_SUCCESS)
							Else
' Report back to the log that we failed deleting the file
								result=Log_data(now & " - Unable to remove orphaned file: " & tmp,EVENT_FAILED)
							End If	
' Clear the error log
							Err.Clear
						Else
' Report back to the log that there's a file there, but not being removed.
							result=Log_data(now & " - Not removing identified orphaned file: " & tmp,EVENT_SUCCESS)
						End If	
					End If	
				End If	
			End If	
		End If	
	Next	
End Function

Function Read_Vid_Dirs(file,key)
' Read_Vid_Dirs function - written by Andy Kruta
' This function reads the file specified (sage.properties) and determines the defined 
' video directories and returns the values in a public array named "vid_dir".

' Define variables for use in this function
	Dim filesysobj, ini, ini_str, vid_tmp_str, vid_tmp_array, dir, counter
' Set the values of some variables
	set FileSysObj = CreateObject("Scripting.FileSystemObject")
' Check to make sure the file specified really exists
	If FileSysObj.FileExists(file) Then
' Open the text file
     	Set ini = FileSysObj.OpenTextFile( file, 1, False)
' Run through each line performing actions until we get to the last line of the file
          	Do While ini.AtEndofStream =False
' Read a line from the text file
	          	ini_str=ini.readline
' Make sure that the line read in isn't commented out
	          	If Left(ini_str,1) <> "#" Then
' Make sure the line has an equals sign in it
					If InStr(ini_str,"=") Then
' Make sure the key value specified is in the line read in
						If InStr(ini_str,key) Then
' Clean up the list of video directories (removing the \: and \\ in the sage.properties file)	
							vid_tmp_str=Replace(Replace(Replace(ini_str, key & "=", ""),"\:",":"),"\\","\")
' Create an array of the video directories spliting at the semicolon as a delimiter
							vid_tmp_array = Split(vid_tmp_str, ";") 
' Setup counter as a zero value variable
							counter = 0
' Parse through the video directories array and perform actions for each element
							For Each dir In vid_tmp_array
' Check to make sure that we don't have an empty element
								If dir <> "" Then
' Increment the counter
									counter = counter +1 
' Redefine the public video directory array incrementing the element limit by 1
									ReDim preserve vid_dir(counter)
' Add the direcotry	to the public video directory array								
									vid_dir(counter-1) = Left(dir,InStr(1,dir,",") - 1)					
								End If	
							Next	
						End If
					End If	
				End If
          	Loop
' Close the ini file
	ini.close
	End If
End Function

Function Log_data(text,status)
' Make sure any errors during logging are ignored, but if logging isn't working, there are bigger problems with the system.
	On Error Resume Next
' Check to see if the user has specified to use the event log instead of a flat text file.
	If log_type = "text" Then
' Create a variable
		Dim Log_name, fso
' Determine if the user wants a single log, or to rotate logs based on the date run
		If rotate_logs = True Then
' If it's a rotating log, then parse through the date and make a name with standard chars in the name
	 		Log_name = "comskip_" & replace(Replace(Left(now,InStr(1,now," ")),"/","")," ","") & ".log"
		Else
' If it's a single log, set the name
			Log_name = "comskip.log"
		End If	
' Setup the variable as a file system object
		Set fso = CreateObject("Scripting.FileSystemObject")
' Blah, I'm tired of writing comments
' Check to make sure the folder 
		If Not fso.FolderExists(Log_dir) Then
' Create the log folder since it didn't exist
			fso.CreateFolder(Log_dir)
		End If	
' Check to see if the log already exists
		If Not fso.FileExists(Log_dir & Log_name) Then
' If the log doesn't already exist, create it and post the first information to the log
			Set logfile= fso.CreateTextFile(Log_dir & Log_name, True) 
			logfile.writeline( now	 & " - comskip automation log")
		Else
' Open the log file for appending since it already existed
			Set logfile = fso.OpenTextFile(Log_dir & Log_name, ForAppending, True) 
		End If	
' Write the text provided into the log file
		If showiegui <> False Then
			ProcessStatus text
' 			checkquit
		End If	
		logfile.WriteLine(text)
' Close the log file
		logfile.Close 
	End If	
' Determine if the user specified to have all logs pointed to the event log
	If log_type = "event_log" Then
' Post the text to the event log with the status determined at function runtime
		wshshell.LogEvent status, text
	End If	
End Function	

Function Rotate_old_logs
	Dim fso2
	Set fso2=CreateObject("scripting.filesystemobject")
	If fso2.FolderExists(Log_dir) Then
		Set fsoLogfolder=fso2.getfolder(Log_dir)
' Perform actions for each file in the folder
		For each tmp in fsoLogfolder.files
' Parse the files so that we're only seeing the mpg files
			If Right(tmp,4) = ".log" Then
				Set logfile = fso2.GetFile(tmp)
				orgdate=logfile.DateCreated
				if DateDiff("D", orgdate, now) > old_log_date Then
' Remove the old log file 
' 					logfile.Delete
' Determine errorlevel returned from attempting to delete file
					If Err.Number = 0 Then
' Report back to current log that old log was removed
						result=Log_data(now & " - Successfully removed log file: " & tmp,EVENT_SUCCESS)
					Else
' Report back to current log that old log was unable to be removed
						result=Log_data(now & " - Unable to remove log file: " & tmp,EVENT_FAILED)
					End If	
				End If	
			End If	
		Next	
	End If	
End Function

Function Get_sagetv_dir() 
' Set the initial registry key to search in
	SWkey="SOFTWARE\Microsoft\Windows\CurrentVersion\Installer\UserData\S-1-5-18\Components"
' Simply saying we're going to search the local machine - this could be changed to a remote pc, but I wouldn't
	strcomputername="."
' Set some required object variables
	set objRegObj = WScript.CreateObject("RegObj.Registry")
	Set objRemoteRegistry = objRegObj.RemoteRegistry(strcomputername)
	Set objRegRootKey = objRemoteRegistry.RegKeyFromString("\HKEY_LOCAL_MACHINE\" & SWkey)
' We're going to bump into some errors through the next few steps on purpose, continue when we do. :)
	On Error resume Next
' Perform actions for each sub-registry key of the specified location (SWKey)
	For Each objSubKey In objRegRootKey.SubKeys
' Perform a "key_search" of each sub key.  This is where it gets interesting
			result= key_search(strcomputername, SWkey & "\" & objSubKey.Name)
' If we didn't get a zero-byte return, this is our answer
			If result <> "" Then
' Return the result from "key_search" as the answer
				Get_sagetv_dir = result
' Exit the function
				Exit Function
			End If	
' Slow down the script to try not to consume too much of the processor. :)
			WScript.Sleep(0.9)
	Next	
' Check to see if we found a result at all...
	If result = "" Then
' Return back a bogus answer to query off of in case we didn't find anything 
		Get_sagetv_dir = "notfound"
	End If		
end function 


Function key_search(strComputer, strKeyPath)
' Setup the wscript.shell as an object
	Set WshShell = WScript.CreateObject("WScript.Shell")
' Open the registry
	Set oReg=GetObject("winmgmts:{impersonationLevel=impersonate}!\\" &_ 
	strComputer & "\root\default:StdRegProv")
' Enumerate all of the values in the specified registry key 
	oReg.EnumValues HKEY_LOCAL_MACHINE, strKeyPath,_
   	arrValueNames, arrValueTypes
' Run through each of the enumerated values to search for the sagetv information
	For I=0 To UBound(arrValueNames)
' Check to see if "SageTV.exe" is in the string returned 
		If InStr(1,WshShell.RegRead("HKEY_LOCAL_MACHINE\"&strKeyPath&"\"&arrValueNames(I)), "SageTV.exe") Then
' Return the value we found
			key_search = WshShell.RegRead("HKEY_LOCAL_MACHINE\"&strKeyPath&"\"&arrValueNames(I))
		End If	
	Next
End Function


Sub checkquit()
' This sub is not used currently since I disabled the cancel button because it wasn't working . ;)
	If IsQuit()=True Then
		result=Log_data(now & " - User interupted process.",EVENT_FAILED)
    	WScript.Quit
	End If
End Sub	

Private Sub StartIE(strTitel)
' Declare some variables
    Dim objDocument
    Dim objWshShell
    Set IEObj = CreateObject("InternetExplorer.Application")
' Set some properties of the IE window
    IEObj.height = 230
    IEObj.width = 400
    IEObj.menubar = False
    IEObj.toolbar = false
    IEObj.statusbar = false
    IEObj.addressbar = false
    IEObj.resizable = False
    IEObj.navigate ("about:blank")
' Wait until IE has finished loading
    While (IEObj.busy)
    Wend
' Create the IE document
    set objDocument = IEObj.document 
' Write the details of the IE document
    WriteHtmlToDialog objDocument, strTitel
    set objTextLine1 = IEObj.document.all("txtMilestone")
    set objTextLine2 = IEObj.document.all("txtRemarks")
    Set objProgressBar = IEObj.document.all("pbText")
    set objQuitFlag = IEObj.document.Secret.pubFlag
    objTextLine1.innerTEXT = ""
    objTextLine2.innerTEXT = ""
' By default, everything is invisible with IE, make it visible
    IEObj.visible = True
' Set IE as the foreground
	Set objWSHShell = WScript.CreateObject("WScript.Shell")
    objWshShell.AppActivate("Microsoft Internet Explorer")
End Sub

Private Function CloseIE()
' Make sure errors don't slow us down.. we don't need no stinkin' errors.. lol :)
	On Error Resume Next
' Close IE
	IEObj.quit
End Function 

Private sub TextBody(sNewText)
' Make sure errors don't slow us down.. we don't need no stinkin' errors.. lol :)
	On Error Resume Next
' Set the text body of the IE document
	objTextLine1.innerTEXT = sNewText
End Sub

Private sub ProcessStatus(sNewText)
' Make sure errors don't slow us down.. we don't need no stinkin' errors.. lol :)
	On Error Resume Next
' Set the process status text of the IE document
	objTextLine2.innerTEXT = sNewText
End Sub

Private function IsQuit()
' This script isn't used currently since I disabled the cancel button
	On Error Resume Next
	IsQuit=True
	If objQuitFlag.Value<>"quit" Then
	    IsQuit=False
	Else
		IEObj.quit
		WScript.Quit
	End If
End Function

Private Sub WriteHtmlToDialog(objDocument, strTitel)
' Write the HTML of the IE document
    objDocument.Open
    objDocument.Writeln "<title>" & strTitel & "</title> "
    objDocument.Writeln "<style>"
    objDocument.Writeln " BODY {background: Silver} BODY { overflow:hidden }"
    objDocument.Writeln " P.txtStyle {color: Navy; font-family: Verdana; " _
        & " font-size: 10pt; font-weight: bold; margin-left: 10px } "
    objDocument.Writeln " input.pbStyle {color: Navy; font-family: Wingdings; " _ 
         & " font-size: 10pt; background: Silver; height: 20px; " _
         & " width: 340px } " 
    objDocument.Writeln "</style>"
    objDocument.Writeln "<div id=""objProgress"" class=""Outer""></div>"
' Write out text lines... 
     objDocument.Writeln "<P id=txtMilestone class='txtStyle' style='margin-left: 10px'> </P>"
    objDocument.Writeln "<P id=txtRemarks class='txtStyle' style='margin-left: 10px' ></P>"
    objDocument.Writeln "<CENTER>"
' Write progress bar
    objDocument.Writeln "<input type='text' id='pbText' class='pbStyle' value='' >" 
    objDocument.Writeln "<br><br>" ' space down a little
' This is commented out since I couldn't get the cancel button to properly stop the entire script
'     objDocument.Writeln "<input type='button' value='Cancel' " _
'                 & " onclick='SetReturnFlag(""quit"")' >"
    objDocument.Writeln "</CENTER>" 
    ' write hidden object...
    objDocument.Writeln "<form name='secret' >" _
                & " <input type='hidden' name='pubFlag' value='run' >" _
                & "</form>" 
    objDocument.Writeln "<SCRIPT LANGUAGE='VBScript' >" 
' Write "local script" to handle cmdCancel_Click event...
    objDocument.Writeln "Sub SetReturnFlag(sFlag)"
    objDocument.Writeln " secret.pubFlag.Value = sFlag"
    objDocument.Writeln " txtMileStone.style.color = ""Red"" "
    objDocument.Writeln " txtRemarks.style.color = ""Red"" "
    objDocument.Writeln "End Sub" 
' Progress bar
    objDocument.Writeln "Function PctComplete(nPct)"
    objDocument.Writeln "pbText.Value = String(nPct,"" "") & String(4,""n"")"
    objDocument.Writeln "End Function"
' Calc progress bar and direction
    objDocument.Writeln "Sub UpdateProgress()"
    objDocument.Writeln "Dim intStep"
    objDocument.Writeln "Dim intDirection"
    objDocument.Writeln "If (IsNull(objProgress.getAttribute(""Step"")) = True) Then"
    objDocument.Writeln "intStep = 0"
    objDocument.Writeln "Else"
    objDocument.Writeln "intStep = objProgress.Step"
    objDocument.Writeln "End If"
    objDocument.Writeln "if (IsNull(objProgress.GetAttribute(""Direction""))=True) Then"
    objDocument.Writeln "intDirection = 0"
    objDocument.Writeln "Else"
    objDocument.Writeln "intDirection = objProgress.Direction"
    objDocument.Writeln "End If"
    objDocument.Writeln "if intDirection=0 then"
    objDocument.Writeln "intStep = intStep + 1"
    objDocument.Writeln "else"
    objDocument.Writeln "intStep = intStep - 1"
    objDocument.Writeln "end if"
    objDocument.Writeln "Call PctComplete(intStep)"
    objDocument.Writeln "if intStep>=23 then"
    objDocument.Writeln "intDirection=1"
    objDocument.Writeln "end if"
    objDocument.Writeln "if intStep<=0 then"
    objDocument.Writeln "intDirection=0"
    objDocument.Writeln "end if"
    objDocument.Writeln "objProgress.SetAttribute ""Step"", intStep"
    objDocument.Writeln "objProgress.SetAttribute ""Direction"", intDirection"
    objDocument.Writeln "Window.setTimeout GetRef(""UpdateProgress""), " & conBarSpeed
    objDocument.Writeln "End Sub"
' Timeout function - makes sure it's not just hung
    objDocument.Writeln "Sub DialogHardTimeout()"
    objDocument.Writeln "SetReturnFlag(""quit"")"
    objDocument.Writeln "End sub"
    objDocument.Writeln "Sub Window_OnLoad()"
    objDocument.Writeln "theleft = (screen.availWidth - document.body.clientWidth) / 2"
    objDocument.Writeln "thetop = (screen.availHeight - document.body.clientHeight) / 2"
    objDocument.Writeln "window.moveTo theleft,thetop"
    objDocument.Writeln "Window.setTimeout GetRef(""UpdateProgress""), " & conBarSpeed
    objDocument.Writeln "Window.setTimeout GetRef(""DialogHardTimeout""), " & conForcedTimeOut
    objDocument.Writeln "End Sub"
    objDocument.Writeln "</SCRIPT>"
    objDocument.Close 
End Sub
